# Contribution guide
Thanks for your interest in contributing to this project!

As stated in the README, there are a lot of down-stream dependencies on these images, so please understand that it can make it complicated on merging your pull request.

We'd love to have your help, but it might be best to explain your intentions first before contributing.

# Project dependencies
You must have these installed on your system.
* Docker (container system): https://www.docker.com/products/docker-desktop

# How things work
1. All files are stored in the `/src` folder
1. Github Actions will automatically build and deploy the images

# Running things locally

To run a build, simply run `./dev.sh` (with Docker Desktop Running). This will automatically build the beta images on your local machine. If you want to only build a specific version, you pass it a version you want to build (example: `./dev.sh 8.1`)

#### Viewing the images
After running the build, you should be able to run `docker images` to see all available images on your machine. Everything built with `./dev.sh` will be tagged `serversideup/php:beta-*`.

### Beta Images
| ⚙️ Variation | 🚀 Version |
| ------------ | ---------- |
| cli          | [![serversideup/php:beta-8.2-cli](https://img.shields.io/docker/image-size/serversideup/php/beta-8.2-cli?label=serversideup%2Fphp%3Abeta-8.2-cli)](https://hub.docker.com/r/serversideup/php/?name=beta-8.2-cli&page=1&ordering=-name)<br />[![serversideup/php:beta-8.1-cli](https://img.shields.io/docker/image-size/serversideup/php/beta-8.1-cli?label=serversideup%2Fphp%3Abeta-8.1-cli)](https://hub.docker.com/r/serversideup/php/?name=beta-8.1-cli&page=1&ordering=-name)<br />[![serversideup/php:beta-8.0-cli](https://img.shields.io/docker/image-size/serversideup/php/beta-8.0-cli?label=serversideup%2Fphp%3Abeta-8.0-cli)](https://hub.docker.com/r/serversideup/php/?name=beta-8.0-cli&page=1&ordering=-name)<br />[![serversideup/php:beta-7.4-cli](https://img.shields.io/docker/image-size/serversideup/php/beta-7.4-cli?label=serversideup%2Fphp%3Abeta-7.4-cli)](https://hub.docker.com/r/serversideup/php/?name=beta-7.4-cli&page=1&ordering=-name) |
| fpm          | [![serversideup/php:beta-8.2-fpm](https://img.shields.io/docker/image-size/serversideup/php/beta-8.2-fpm?label=serversideup%2Fphp%3Abeta-8.2-fpm)](https://hub.docker.com/r/serversideup/php/?name=beta-8.2-fpm&page=1&ordering=-name)<br />[![serversideup/php:beta-8.1-fpm](https://img.shields.io/docker/image-size/serversideup/php/beta-8.1-fpm?label=serversideup%2Fphp%3Abeta-8.1-fpm)](https://hub.docker.com/r/serversideup/php/?name=beta-8.1-fpm&page=1&ordering=-name)<br />[![serversideup/php:beta-8.0-fpm](https://img.shields.io/docker/image-size/serversideup/php/beta-8.0-fpm?label=serversideup%2Fphp%3Abeta-8.0-fpm)](https://hub.docker.com/r/serversideup/php/?name=beta-8.0-fpm&page=1&ordering=-name)<br />[![serversideup/php:beta-7.4-fpm](https://img.shields.io/docker/image-size/serversideup/php/beta-7.4-fpm?label=serversideup%2Fphp%3Abeta-7.4-fpm)](https://hub.docker.com/r/serversideup/php/?name=beta-7.4-fpm&page=1&ordering=-name) |
| fpm-apache   | [![serversideup/php:beta-8.2-fpm-apache](https://img.shields.io/docker/image-size/serversideup/php/beta-8.2-fpm-apache?label=serversideup%2Fphp%3Abeta-8.2-fpm-apache)](https://hub.docker.com/r/serversideup/php/?name=beta-8.2-fpm-apache&page=1&ordering=-name)<br />[![serversideup/php:beta-8.1-fpm-apache](https://img.shields.io/docker/image-size/serversideup/php/beta-8.1-fpm-apache?label=serversideup%2Fphp%3Abeta-8.1-fpm-apache)](https://hub.docker.com/r/serversideup/php/?name=beta-8.1-fpm-apache&page=1&ordering=-name)<br />[![serversideup/php:beta-8.0-fpm-apache](https://img.shields.io/docker/image-size/serversideup/php/beta-8.0-fpm-apache?label=serversideup%2Fphp%3Abeta-8.0-fpm-apache)](https://hub.docker.com/r/serversideup/php/?name=beta-8.0-fpm-apache&page=1&ordering=-name)<br />[![serversideup/php:beta-7.4-fpm-apache](https://img.shields.io/docker/image-size/serversideup/php/beta-7.4-fpm-apache?label=serversideup%2Fphp%3Abeta-7.4-fpm-apache)](https://hub.docker.com/r/serversideup/php/?name=beta-7.4-fpm-apache&page=1&ordering=-name) |
| fpm-nginx    | [![serversideup/php:beta-8.2-fpm-nginx](https://img.shields.io/docker/image-size/serversideup/php/beta-8.2-fpm-nginx?label=serversideup%2Fphp%3Abeta-8.2-fpm-nginx)](https://hub.docker.com/r/serversideup/php/?name=beta-8.2-fpm-nginx&page=1&ordering=-name)<br />[![serversideup/php:beta-8.1-fpm-nginx](https://img.shields.io/docker/image-size/serversideup/php/beta-8.1-fpm-nginx?label=serversideup%2Fphp%3Abeta-8.1-fpm-nginx)](https://hub.docker.com/r/serversideup/php/?name=beta-8.1-fpm-nginx&page=1&ordering=-name)<br />[![serversideup/php:beta-8.0-fpm-nginx](https://img.shields.io/docker/image-size/serversideup/php/beta-8.0-fpm-nginx?label=serversideup%2Fphp%3Abeta-8.0-fpm-nginx)](https://hub.docker.com/r/serversideup/php/?name=beta-8.0-fpm-nginx&page=1&ordering=-name)<br />[![serversideup/php:beta-7.4-fpm-nginx](https://img.shields.io/docker/image-size/serversideup/php/beta-7.4-fpm-nginx?label=serversideup%2Fphp%3Abeta-7.4-fpm-nginx)](https://hub.docker.com/r/serversideup/php/?name=beta-7.4-fpm-nginx&page=1&ordering=-name) |


#### Running a test web server:
This is helpful for testing things out:
```sh
docker run --rm -v $(pwd):/var/www/html -p 80:80 -p 443:443 serversideup/php:beta-8.1-fpm-nginx
```